@@ -4,7 +4,7 @@
 #'
 #' @details
 #' The CSS is heavily inspired from the default one of the docco project :
-#' \url{https://jashkenas.github.io/docco/}.
+#' \url{https://ashkenas.com/docco/}.
 #'
 #' @param fig_width Default width (in inches) for figures
 #' @param fig_height Default width (in inches) for figures
@@ -34,63 +34,32 @@ html_docco <- function(fig_width = 6,
                        lightbox = TRUE,
                        thumbnails = TRUE,
                        gallery = FALSE,
+                       use_bookdown = FALSE,
                        pandoc_args = NULL,
                        md_extensions = NULL,
                        mathjax = "rmdformats",
-                       use_bookdown = FALSE,
                        ...) {
 
-  ## js and css dependencies
-  extra_dependencies <- list(rmarkdown::html_dependency_jquery(),
-                             rmarkdown::html_dependency_jqueryui(),
-                             html_dependency_navigation(),                             
-                             html_dependency_bootstrap("bootstrap"),
-                             html_dependency_magnific_popup(),
-                             html_dependency_docco())
-
-  ## Force mathjax arguments
-  if (!is.null(mathjax)) {
-    pandoc_args <- c(pandoc_args,
-                     "--mathjax",
-                     "--variable", paste0("mathjax-url:", default_mathjax()))
-  }
-  if (lightbox) { pandoc_args <- c(pandoc_args, "--variable", "lightbox:true") }
-  if (thumbnails) { pandoc_args <- c(pandoc_args, "--variable", "thumbnails:true") }
-  if (gallery) {
-    pandoc_args <- c(pandoc_args, "--variable", "gallery:true")
-  } else {
-    pandoc_args <- c(pandoc_args, "--variable", "gallery:false")
-  }
-
-  ## Merge "extra_dependencies"
-  extra_args <- list(...)
-  if ("extra_dependencies" %in% names(extra_args)) {
-    extra_dependencies <- append(extra_dependencies, extra_args[["extra_dependencies"]])
-    extra_args[["extra_dependencies"]] <- NULL
-    extra_args[["mathjax"]] <- NULL
-  }
-
-  
-  ## Call rmarkdown::html_document
-  html_document_args <- list(
-    template = system.file("templates/html_docco/html_docco.html", package = "rmdformats"),
-    extra_dependencies = extra_dependencies,
-    fig_width = fig_width,
-    fig_height = fig_height,
-    fig_caption = fig_caption,
-    highlight = highlight,
-    pandoc_args = pandoc_args,
-    md_extensions = md_extensions
-  )
-  html_document_args <- append(html_document_args, extra_args)
-  if (use_bookdown) {
-      html_document_func <- bookdown::html_document2
-  } else {
-      html_document_func <- rmarkdown::html_document
-  }
-
-  do.call(html_document_func, html_document_args)
-
+    html_template(
+        template_name = "html_docco",
+        template_path = "templates/template.html",
+        template_dependencies = list(
+            html_dependency_docco()
+        ),
+        pandoc_args = pandoc_args,
+        fig_width = fig_width,
+        fig_height = fig_height,
+        fig_caption = fig_caption,
+        highlight = highlight,
+        lightbox = lightbox,
+        thumbnails = thumbnails,
+        gallery = gallery,
+        use_bookdown = use_bookdown,
+        md_extensions = md_extensions,
+        mathjax = mathjax,
+        ...
+    )
+    
 }
 
 
